@@ -13,7 +13,7 @@ cd "$DIR"
 
 mkdir -p _cpan/CPAN
 echo '1;' >> _cpan/CPAN/MyConfig.pm
-if ! perl -I_cpan setup-deps.pl </dev/null >setup-deps.log 2>&1
+if ! perl -I_cpan -Iaux/lib/perl5 setup-deps.pl </dev/null >setup-deps.log 2>&1
 then
   if grep '^read timeout.*HTTP' setup-deps.log >/dev/null
   then
@@ -31,7 +31,7 @@ then
   gzip -cd Mozilla-CA.tar.gz | tar xvf -
 fi
 
-osname=`uname -s | sed -e 's/[0-9.-]*$//'`
+osname=`uname -s | sed -e 's/_NT-.*$/_NT/; s/^MINGW[0-9]*/CYGWIN/'`
 cputype=`uname -m`
 case "$osname-$cputype" in
   Linux-x86_64 | Darwin-x86_64 | CYGWIN_NT-* )
@@ -43,10 +43,18 @@ if [ -f xtract."$osname" ]
 then
   chmod +x xtract."$osname"
 else
-  echo "Unable to download a prebuilt xtract executable; attempting to"
-  echo "build one from xtract.go.  A Perl fallback is also available, and"
-  echo "will be used if necessary, so please disregard any errors below."
-  go build -o xtract."$osname" xtract.go
+  if hash go 2>/dev/null
+  then
+    echo "Unable to download xtract executable; building from xtract.go."
+    go build -o xtract."$osname" xtract.go
+  fi
+  if [ ! -f xtract."$osname" ]
+  then
+    echo -e "Unable to download xtract executable. Please execute the following:\n\n"
+    echo -e "  ./ftp-cp ftp.ncbi.nlm.nih.gov /entrez/entrezdirect xtract.$osname.gz"
+    echo -e "  gunzip -f xtract.$osname.gz\n"
+    echo -e "  chmod +x xtract.$osname\n"
+  fi
 fi
 
 echo ""
